@@ -23,6 +23,29 @@ import numpy as np
 
 Logger = logging.getLogger()
 
+
+class MementoDirectives:
+	def __init__(self, AttributeList, RenameDictionaryForInit = {}):
+		'''
+		
+		Parameters
+		-----
+		AttributeList : list
+			List of the attributes that the Memento must save.
+			In principle, they can be base types (e.g. int, float, numpy array)
+			or user defined types.
+			
+			"How to store" the attributes is a matter taken care by... ?
+			
+		RenameDictionaryForInit : dictionary
+			Certain attributes 
+			
+		
+		'''
+		
+		pass
+
+
 def EnsureIsArray(x):
 	if np.isscalar(x):
 		return np.array([x])
@@ -1615,6 +1638,12 @@ class Vector(object):
 	-------------------
 	v : a v = [vx,vy] type
 
+
+	Set of Parameters 4
+	-------------------
+	A : 
+	B : 
+
 	'''
 
 	#================================
@@ -1625,6 +1654,7 @@ class Vector(object):
 				v = None, # [vx,vy] array
 				V = None, # a vector object
 				Angle = None,
+				A = None, B = None,
 				XYOrigin = [0,0], Length = 1, IsUnitVector = False):
 
 		self._IsUnitVector = IsUnitVector
@@ -1638,6 +1668,11 @@ class Vector(object):
 		elif CheckArg([v]):
 			self.v = v          # _v is assigned
 
+		elif CheckArg([A,B]):
+			vx = B[0] - A[0]
+			vy = B[1] - A[1]
+			self.v = [vx,vy] # _v is assigned
+
 		elif CheckArg([Angle, Length]):
 			if Length >0:
 				self.v = RotVersor(np.array([1,0]) *Length, Angle)  # _v is assigned
@@ -1665,6 +1700,9 @@ class Vector(object):
 				(self.v[0], self.v[1], (self.Angle * 180/np.pi),
 				self.XYOrigin[0], self.XYOrigin[1]))
 		return StrMsg
+	
+	def __repr__(self):
+		return self.__str__()
 
 # 	#======================
 # 	# FUN: __repr__
@@ -1795,6 +1833,7 @@ class Vector(object):
 		>>> UnitVector.vAngle +=  Angle
 		'''
 		self.vAngle = self.vAngle + Angle
+		return self
 
 
 	#======================
@@ -1843,6 +1882,16 @@ class Vector(object):
 		ax.arrow(x0,y0,Length*(x1-x0), Length*(y1-y0),
 				   head_width = ArrowWidth, head_length= ArrowLength,
 								   fc=Color, ec=Color)
+		
+	def Dot(self, V ):
+		'''
+		Implements the dot product between the current vector and the vector V
+		
+		'''
+		
+		return np.dot(self.v, V.v)
+	
+		
 #============================================================================
 #	 CLASS: UnitVector
 #==============================================================================
@@ -1852,8 +1901,9 @@ class UnitVector(Vector):
 			  vy = None,
   				V = None,
 			   Angle = None,
+			   A = None, B = None,
 			    XYOrigin = [0,0]):
-		Vector.__init__(self,  vx = vx, vy= vy, v = v, V = V ,
+		Vector.__init__(self,  vx = vx, vy= vy, v = v, V = V , A = A, B = B,
 				  Angle = Angle, XYOrigin = XYOrigin,
 				  IsUnitVector = True)
 
@@ -2185,11 +2235,24 @@ def AngleBetweenVersors(V1 : Vector, V2 : Vector):
 		Return the angle comprised between two versors (or vector),
 		in radians
 		
+	'''
+	Angle = np.abs(V1.Angle - V2.Angle)
+	return Angle
+
+#================================================================
+#  AngleIncluded
+#================================================================
+def AngleIncluded(V1 : Vector, V2 : Vector):
+	'''
+		Return the angle comprised between two versors (or vector),
+		in radians
 		
 	'''
 	Angle = np.abs(V1.Angle - V2.Angle)
 	return Angle
 
+def Dot(V1 : Vector, V2 : Vector):
+	return np.dot(V1.v, V2.v)
 
 #================================================================
 #  AngleBetweenPoints
@@ -2417,6 +2480,9 @@ class FileIO:
 			Line = Line.strip()
 			if Line != '':
 				Tokens = Line.split(Delimiter)
+				if len(Tokens) < 2:
+					raise WiserException("I read only one number, while I expected two. Possible solution: check the delimiter character",
+						  By = "ReadXYFile")
 				x[iLine] = float(Tokens[0])
 				y[iLine] = float(Tokens[1])
 
